/**
 * \addtogroup weAutSys
 * @{
 * \addtogroup appLaySup
 * @{
 * \addtogroup comTypes
 * @{
 *
 * \file config.h
 *
 *  \ref intro_sec "weAutSys"' configuration settings
 *
 *  This file contains some definitions concerning software and hardware
 *  configuration. These settings influence the compilation and building
 *  process and can't be changed later at runtime.
 *
 *  This file (in the serial bootloader project) is part of weAutSys &nbsp;
 *          <<a href="http://weinert-automation.de">weinert-automation.de</a>>
 *  <br />It is also used for the \ref bootSup "serial bootloader".<br />
 *  Mainly by an include file mechanism (config_<platformName>.h) a number
 *  of different (AVR-) platforms are supported.
 *
 * &nbsp; \ref copyLicNote " Copyright &copy; " 2014  Albrecht Weinert, Bochum
 * \author  Albrecht Weinert  &nbsp; <<a href="http://a-weinert.de">a-weinert.de</a>>
 * 1
 * 25.01.2017
 */
//  SVN last change by A. Weinert

/** @} */ // Doxygen addtogroup   comTypes
/** @} */ // Doxygen addtogroup appLaySup

#ifndef CONFIG_H
#define CONFIG_H

/**
 * \addtogroup appLaySup
 * @{
 * \addtogroup comTypes
 * @{
 */

//--- platform specific include     ----------------------------------------

#define __header(x) #x                          // it's a kind
#define _header(x) __header(arch/config_##x.h) // of
#define header(x) _header(x)                  // magic

#include header(PLATFORM)


#ifndef USART_IN_APP_WITH_INT
# define USART_IN_APP_WITH_INT 0 //!< UART uses no interrupt in application \showinitializer
#endif

#ifndef STD_BAUD   // if not yet set set to default (for Eclipse's sake only)
# define STD_BAUD 38400  //!< Standard resp. used baudrate  \showinitializer
#endif

#ifndef GN_LED_INV   // standard case LED is high-active (1 = on)
# define GN_LED_INV //!< invert gn LED: ! ; no invert: empty \showinitializer
#endif

#ifndef RD_LED_INV   // standard case LED is high-active (1 = on)
# define RD_LED_INV //!< invert rd LED: ! ; no invert: empty \showinitializer
#endif

/** The trampolin hack is used
 *
 *  This value is true (!= 0) if the trampolin hack (+ linker relaxation) is
 *  used (and hopefully works) on large ATmegas with more than 128K flash.
 *
 *  As of January 2014 this is a "feature" of arv-gcc, thus avoiding the
 *  introduction of 24 bit pointers (for label as value) as well as a correct
 *  and consistent handling of EIND.
 *
 *  This marco defines a property of the (AVR gcc) toolchain. The only place
 *  it is used (or prepared to be used as of Nov. 2014) is the
 *  \ref intro_sec "weAutSys"  implementation of \ref pt "protothreads".
 *
 *  \showinitializer
 */
#define TRAMPOLIN_USE 1

/** @} */ // Doxygen addtogroup comTypes
/** @} */ // Doxygen addtogroup appLaySup

/**
 * \addtogroup llSySer
 * @{
 * \addtogroup swDebaid
 * @{
 */

// Set level (0 off 1 low 2 medium 3 high) for .................

#if compileDebugs

#define DEBUG_ETH  3  //!< Ethernet driver debugging \showinitializer
#define DEBUG_DHCP 3  //!< DHCP debugging \showinitializer
#define DEBUG_NTP  3  //!< NTP debugging \showinitializer
#define DEBUG_TEL  3  //!< Telnet debugging \showinitializer
#define DEBUG_MOD  3  //!< Modbus debugging \showinitializer
#define DEBUG_ARP  3  //!< ARP debugging \showinitializer
#define DEBUG_ApL  3  //!< Application layer debugging \showinitializer
#define DEBUG_EEP  3  //!< EEPROM debugging \showinitializer
#define DEBUG_UART 3  //!< UART (input) debugging \showinitializer
#define DEBUG_SMC  3  //!< SMC (small memory card) debugging \showinitializer

#endif

/** @} */ // Doxygen addtogroup swDebaid
/** @} */ // Doxygen addtogroup llSySer

/* \addtogroup bootSup
 * @{
 */

#ifndef USE_BOOTLOADER_PRESET
# define USE_BOOTLOADER_PRESET 2
#endif
/** Have and use a bootloader
 *
 *  This value determines the existence and usage of a bootloader:<br />
 *  0: no bootloader or at least no bootloader integration
 *  1: bootloader area used / bootloader existing
 *  2: bootloader fully integrated: application programme may use all
 *     No Read-While-Write (NRWW) flash section functions and constants.
 *
 *  Fully integrated means that all Controller resets go through the
 *  bootloader and the bootloader will not enter the program (=x00000) without
 *  having done all basic initialisations. The latter hence can be omitted
 *  from system/application software. Full integration also means that the
 *  bootloader may be entered by (\ref shellCLI "CLI") command.
 *  \showinitializer
 */
#define USE_BOOTLOADER USE_BOOTLOADER_PRESET


/** @} */ // Doxygen addtogroup bootSup

#endif /* CONFIG_H */
/** @} */ // Doxygen addtogroup weAutSys
